aboutsummaryrefslogtreecommitdiffstats
path: root/build
diff options
context:
space:
mode:
authorFelix Lange <fjl@twurst.com>2015-07-23 00:48:40 +0800
committerFelix Lange <fjl@twurst.com>2015-07-23 00:51:45 +0800
commit3f047be5aa93b6222506445414ca909dd59c7eeb (patch)
tree8508a1f17df8484c3a20aa1dddf3abede7797a26 /build
parentf4acdea402ab3e3387a74c89dcca555bbc6dd9a7 (diff)
downloadgo-tangerine-3f047be5aa93b6222506445414ca909dd59c7eeb.tar
go-tangerine-3f047be5aa93b6222506445414ca909dd59c7eeb.tar.gz
go-tangerine-3f047be5aa93b6222506445414ca909dd59c7eeb.tar.bz2
go-tangerine-3f047be5aa93b6222506445414ca909dd59c7eeb.tar.lz
go-tangerine-3f047be5aa93b6222506445414ca909dd59c7eeb.tar.xz
go-tangerine-3f047be5aa93b6222506445414ca909dd59c7eeb.tar.zst
go-tangerine-3f047be5aa93b6222506445414ca909dd59c7eeb.zip
all: update license headers to distiguish GPL/LGPL
All code outside of cmd/ is licensed as LGPL. The headers now reflect this by calling the whole work "the go-ethereum library".
Diffstat (limited to 'build')
-rw-r--r--build/update-license.go24
1 files changed, 16 insertions, 8 deletions
diff --git a/build/update-license.go b/build/update-license.go
index 98c122193..3c18ee40f 100644
--- a/build/update-license.go
+++ b/build/update-license.go
@@ -66,20 +66,20 @@ var (
// its input is an info structure.
var licenseT = template.Must(template.New("").Parse(`
// Copyright {{.Year}} The go-ethereum Authors
// This file is part of go-ethereum.
//
// go-ethereum is free software: you can redistribute it and/or modify
// it under the terms of the GNU {{.License}} as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// go-ethereum is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU {{.License}} for more details.
//
// You should have received a copy of the GNU {{.License}}
-// along with go-ethereum. If not, see <http://www.gnu.org/licenses/>.
+// along with {{.Whole false}}. If not, see <http://www.gnu.org/licenses/>.
`[1:]))
@@ -91,17 +91,25 @@ type info struct {
func (i info) License() string {
if i.gpl() {
return "General Public License"
- } else {
- return "Lesser General Public License"
}
+ return "Lesser General Public License"
}
func (i info) ShortLicense() string {
if i.gpl() {
return "GPL"
- } else {
- return "LGPL"
}
+ return "LGPL"
+}
+
+func (i info) Whole(startOfSentence bool) string {
+ if i.gpl() {
+ return "go-ethereum"
+ }
+ if startOfSentence {
+ return "The go-ethereum library"
+ }
+ return "the go-ethereum library"
}
func (i info) gpl() bool {
@@ -66,20 +66,20 @@ var (
var licenseT = template.Must(template.New("").Parse(`
// Copyright {{.Year}} The go-ethereum Authors
-// This file is part of go-ethereum.
+// This file is part of {{.Whole false}}.
//
// go-ethereum is free software: you can redistribute it and/or modify
@@ -66,20 +66,20 @@ var (
// (at your option) any later version.
//
-// go-ethereum is distributed in the hope that it will be useful,
+// {{.Whole true}} is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of